# daft-ext-macros

Proc macros for [Daft](https://github.com/Eventual-Inc/Daft) extensions.

Most users should depend on [`daft-ext`](https://crates.io/crates/daft-ext) instead.

## License

Apache-2.0
